* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [ServiceNow Integration](https://help.sap.com/docs/leanix/ea/servicenow-integration)
  * Setup in ServiceNow
